@@ -21,6 +21,7 @@ describe 'ceilometer::agent::polling' do
 
   shared_examples_for 'ceilometer-polling' do
 
+    it { is_expected.to contain_class('ceilometer::deps') }
     it { is_expected.to contain_class('ceilometer::params') }
 
     context 'when compute_namespace => true' do
@@ -37,13 +38,16 @@ describe 'ceilometer::agent::polling' do
               :before => /Package\[ceilometer-common\]/
           )
       end
+
+      it 'configures agent compute' do
+        is_expected.to contain_ceilometer_config('compute/instance_discovery_method').with_value('<SERVICE DEFAULT>')
+      end
     end
 
     it 'installs ceilometer-polling package' do
       is_expected.to contain_package('ceilometer-polling').with(
         :ensure => 'latest',
         :name   => platform_params[:agent_package_name],
-        :before => ['Service[ceilometer-polling]'],
         :tag    => ['openstack', 'ceilometer-package'],
       )
     end
@@ -52,12 +56,6 @@ describe 'ceilometer::agent::polling' do
       is_expected.to contain_ceilometer_config('DEFAULT/polling_namespaces').with_value('central,compute,ipmi')
     end
 
-    it 'ensures ceilometer-common is installed before the service' do
-      is_expected.to contain_package('ceilometer-common').with(
-        :before => /Service\[ceilometer-polling\]/
-      )
-    end
-
     [{:enabled => true}, {:enabled => false}].each do |param_hash|
       context "when service should be #{param_hash[:enabled] ? 'enabled' : 'disabled'}" do
         before do
@@ -77,6 +75,17 @@ describe 'ceilometer::agent::polling' do
       end
     end
 
+
+    context 'when setting instance_discovery_method' do
+      before do
+        params.merge!({ :instance_discovery_method   => 'naive' })
+      end
+
+      it 'configures agent compute instance discovery' do
+        is_expected.to contain_ceilometer_config('compute/instance_discovery_method').with_value('naive')
+      end
+    end
+
     context 'with central and ipmi polling namespaces disabled' do
       before do
         params.merge!({
@@ -108,51 +117,52 @@ describe 'ceilometer::agent::polling' do
       end
     end
 
+    context "with polling management enabled" do
+      before { params.merge!(
+        :manage_polling   => true
+      ) }
+
+      it { is_expected.to contain_file('polling').with(
+        'path' => '/etc/ceilometer/polling.yaml',
+      ) }
+    end
+
+    context "with polling management disabled" do
+      before { params.merge!(
+        :manage_polling   => false
+      ) }
+
+      it { is_expected.not_to contain_file('polling') }
+    end
+
     it 'configures central agent' do
       is_expected.to contain_ceilometer_config('coordination/backend_url').with_value( params[:coordination_url] )
     end
 
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'Debian' })
-    end
-
-    let :platform_params do
-      { :agent_package_name => 'ceilometer-polling',
-        :agent_service_name => 'ceilometer-polling' }
-    end
-
-    context 'on Ubuntu operating systems' do
-      before do
-        facts.merge!( :operatingsystem => 'Ubuntu' )
-        platform_params.merge!( :libvirt_group => 'libvirtd' )
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
       end
 
-      it_configures 'ceilometer-polling'
-    end
-
-    context 'on other operating systems' do
-      before do
-        platform_params.merge!( :libvirt_group => 'libvirt' )
+      let :platform_params do
+        case facts[:osfamily]
+        when 'Debian'
+            { :agent_package_name => 'ceilometer-polling',
+              :agent_service_name => 'ceilometer-polling',
+              :libvirt_group      => 'libvirt' }
+        when 'RedHat'
+            { :agent_package_name => 'openstack-ceilometer-polling',
+              :agent_service_name => 'openstack-ceilometer-polling' }
+        end
       end
 
-      it_configures 'ceilometer-polling'
+      it_behaves_like 'ceilometer-polling'
     end
-
   end
 
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat' })
-    end
-
-    let :platform_params do
-      { :agent_package_name => 'openstack-ceilometer-polling',
-        :agent_service_name => 'openstack-ceilometer-polling' }
-    end
-
-    it_configures 'ceilometer-polling'
-  end
 end
