@@ -10,13 +10,14 @@ describe 'ceilometer::db' do
       it { is_expected.to contain_class('ceilometer::db::sync') }
       it { is_expected.to contain_oslo__db('ceilometer_config').with(
         :db_max_retries => '<SERVICE DEFAULT>',
-        :connection     => 'mysql://ceilometer:ceilometer@localhost/ceilometer',
+        :connection     => 'mysql+pymysql://ceilometer:ceilometer@localhost/ceilometer',
         :idle_timeout   => '<SERVICE DEFAULT>',
         :min_pool_size  => '<SERVICE DEFAULT>',
         :max_pool_size  => '<SERVICE DEFAULT>',
         :max_retries    => '<SERVICE DEFAULT>',
         :retry_interval => '<SERVICE DEFAULT>',
         :max_overflow   => '<SERVICE DEFAULT>',
+        :pool_timeout   => '<SERVICE DEFAULT>',
       )}
 
     end
@@ -32,6 +33,7 @@ describe 'ceilometer::db' do
           :database_max_retries    => '11',
           :database_retry_interval => '11',
           :database_max_overflow   => '21',
+          :database_pool_timeout   => '21',
           :sync_db                 => false }
       end
 
@@ -45,6 +47,7 @@ describe 'ceilometer::db' do
         :max_retries    => '11',
         :retry_interval => '11',
         :max_overflow   => '21',
+        :pool_timeout   => '21',
       )}
 
     end
