@@ -14,7 +14,6 @@ describe 'ceilometer::dispatcher::gnocchi' do
     it 'configures gnocchi dispatcher' do
       is_expected.to contain_ceilometer_config('dispatcher_gnocchi/filter_service_activity').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ceilometer_config('dispatcher_gnocchi/filter_project').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_ceilometer_config('dispatcher_gnocchi/url').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ceilometer_config('dispatcher_gnocchi/archive_policy').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ceilometer_config('dispatcher_gnocchi/resources_definition_file').with_value('<SERVICE DEFAULT>')
     end
@@ -23,32 +22,26 @@ describe 'ceilometer::dispatcher::gnocchi' do
       before do
         params.merge!(:filter_service_activity   => false,
                       :filter_project            => 'gnocchi_swift',
-                      :url                       => 'http://foo',
                       :archive_policy            => 'high',
                       :resources_definition_file => 'foo')
       end
       it { is_expected.to contain_ceilometer_config('dispatcher_gnocchi/filter_service_activity').with_value('false') }
       it { is_expected.to contain_ceilometer_config('dispatcher_gnocchi/filter_project').with_value('gnocchi_swift') }
-      it { is_expected.to contain_ceilometer_config('dispatcher_gnocchi/url').with_value('http://foo') }
       it { is_expected.to contain_ceilometer_config('dispatcher_gnocchi/archive_policy').with_value('high') }
       it { is_expected.to contain_ceilometer_config('dispatcher_gnocchi/resources_definition_file').with_value('foo') }
     end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'Debian' })
+  on_supported_os({
+    :supported_os   => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge(OSDefaults.get_facts())
+      end
+
+      it_behaves_like 'ceilometer-gnocchi-dispatcher'
     end
-
-    it_configures 'ceilometer-gnocchi-dispatcher'
-  end
-
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat' })
-    end
-
-    it_configures 'ceilometer-gnocchi-dispatcher'
   end
 
 end
